@@ -1,4 +1,4 @@
-/* GG is a GUI for SDL and OpenGL.
+/* GG is a GUI for OpenGL.
    Copyright (C) 2003-2008 T. Zachary Laine
 
    This library is free software; you can redistribute it and/or
@@ -174,12 +174,14 @@ ModalListPicker::ModalListPicker(Clr color, const DropDownList* relative_to_wnd,
 
 void ModalListPicker::CompleteConstruction()
 {
+    namespace ph = boost::placeholders;
+
     m_lb_wnd->SelRowsChangedSignal.connect(
-        boost::bind(&ModalListPicker::LBSelChangedSlot, this, _1));
+        boost::bind(&ModalListPicker::LBSelChangedSlot, this, ph::_1));
     m_lb_wnd->LeftClickedRowSignal.connect(
-        boost::bind(&ModalListPicker::LBLeftClickSlot, this, _1, _2, _3));
+        boost::bind(&ModalListPicker::LBLeftClickSlot, this, ph::_1, ph::_2, ph::_3));
     GUI::GetGUI()->WindowResizedSignal.connect(
-        boost::bind(&ModalListPicker::WindowResizedSlot, this, _1, _2));
+        boost::bind(&ModalListPicker::WindowResizedSlot, this, ph::_1, ph::_2));
     AttachChild(m_lb_wnd);
     m_lb_wnd->InstallEventFilter(shared_from_this());
 
@@ -194,7 +196,7 @@ void ModalListPicker::CompleteConstruction()
 
 ModalListPicker::~ModalListPicker()
 {
-    // Shut down the ModalEventPump
+    // Exit the modal run
     EndRun();
 }
 
@@ -680,8 +682,8 @@ void DropDownList::Render()
     Pt ul = UpperLeft();
 
     Clr border_color = Disabled() ? DisabledColor(LB()->Color()) : LB()->Color();
-    Clr border_color1 = DarkColor(border_color);
-    Clr border_color2 = LightColor(border_color);
+    Clr border_color1 = DarkenClr(border_color);
+    Clr border_color2 = LightenClr(border_color);
     Clr interior_color = Disabled() ? DisabledColor(LB()->m_int_color) : LB()->m_int_color;
 
 
