@@ -15,7 +15,6 @@
 
 #include <boost/filesystem/fstream.hpp>
 
-#include <GG/DrawUtil.h>
 #include <GG/StaticGraphic.h>
 #include <GG/Layout.h>
 #include <GG/TabWnd.h>
@@ -27,14 +26,13 @@ namespace {
     const GG::Y CONTROL_HEIGHT(30);
     const GG::Y PANEL_CONTROL_SPACING(33);
     const GG::X INDENTATION(20);
-    const GG::X SPIN_WIDTH(92);
+    const GG::X SPIN_WIDTH(128);
     const GG::Y GAL_SETUP_PANEL_HT(PANEL_CONTROL_SPACING * 10);
     const GG::X GalSetupWndWidth()
-    { return GG::X(345 + FontBasedUpscale(300)); }
+    { return GG::X(445 + FontBasedUpscale(300)); }
     const GG::Y GalSetupWndHeight()
     { return GG::Y(FontBasedUpscale(29) + (PANEL_CONTROL_SPACING * 6) + GAL_SETUP_PANEL_HT); }
-    const GG::Pt PREVIEW_SZ(GG::X(300), GG::Y(222));
-    const bool ALLOW_NO_STARLANES = false;
+    const GG::Pt PREVIEW_SZ(GG::X(400), GG::Y(222));
 
     class RowContentsWnd : public GG::Control {
     public:
@@ -79,13 +77,12 @@ namespace {
     class RuleListRow : public GG::ListBox::Row {
     public:
         RuleListRow(GG::X w, GG::Y h, std::shared_ptr<RowContentsWnd> contents) :
-            GG::ListBox::Row(w, h, ""),
+            GG::ListBox::Row(w, h),
             m_contents(std::forward<std::shared_ptr<RowContentsWnd>>(contents))
         {}
 
         RuleListRow(GG::X w, GG::Y h, std::shared_ptr<Wnd> contents, int indentation = 0) :
-            GG::ListBox::Row(w, h, ""),
-            m_contents(nullptr)
+            GG::ListBox::Row(w, h)
         {
             if (contents)
                 m_contents = GG::Wnd::Create<RowContentsWnd>(w, h, std::forward<std::shared_ptr<GG::Wnd>>(contents), indentation);
@@ -148,23 +145,12 @@ namespace {
     };
 
 
-    // persistant between-executions galaxy setup settings, mainly so I don't have to redo these settings to what I want every time I run FO to test something
+    // persistant between-executions game setup settings
     void AddOptions(OptionsDB& db) {
-        db.Add("setup.seed",                    UserStringNop("OPTIONS_DB_GAMESETUP_SEED"),                     std::string("0"),           Validator<std::string>());
-        db.Add("setup.star.count",              UserStringNop("OPTIONS_DB_GAMESETUP_STARS"),                    150,                        RangedValidator<int>(10, 5000));
-        db.Add("setup.galaxy.shape",            UserStringNop("OPTIONS_DB_GAMESETUP_GALAXY_SHAPE"),             DISC,                       RangedValidator<Shape>(SPIRAL_2, RANDOM));
-        db.Add("setup.galaxy.age",              UserStringNop("OPTIONS_DB_GAMESETUP_GALAXY_AGE"),               GALAXY_SETUP_MEDIUM,        RangedValidator<GalaxySetupOption>(GALAXY_SETUP_LOW, GALAXY_SETUP_RANDOM));
-        db.Add("setup.planet.density",          UserStringNop("OPTIONS_DB_GAMESETUP_PLANET_DENSITY"),           GALAXY_SETUP_MEDIUM,        RangedValidator<GalaxySetupOption>(GALAXY_SETUP_LOW, GALAXY_SETUP_RANDOM));
-        db.Add("setup.starlane.frequency",      UserStringNop("OPTIONS_DB_GAMESETUP_STARLANE_FREQUENCY"),       GALAXY_SETUP_MEDIUM,        RangedValidator<GalaxySetupOption>(ALLOW_NO_STARLANES ? GALAXY_SETUP_NONE : GALAXY_SETUP_LOW, GALAXY_SETUP_RANDOM));
-        db.Add("setup.specials.frequency",      UserStringNop("OPTIONS_DB_GAMESETUP_SPECIALS_FREQUENCY"),       GALAXY_SETUP_MEDIUM,        RangedValidator<GalaxySetupOption>(GALAXY_SETUP_NONE, GALAXY_SETUP_RANDOM));
-        db.Add("setup.monster.frequency",       UserStringNop("OPTIONS_DB_GAMESETUP_MONSTER_FREQUENCY"),        GALAXY_SETUP_MEDIUM,        RangedValidator<GalaxySetupOption>(GALAXY_SETUP_NONE, GALAXY_SETUP_RANDOM));
-        db.Add("setup.native.frequency",        UserStringNop("OPTIONS_DB_GAMESETUP_NATIVE_FREQUENCY"),         GALAXY_SETUP_MEDIUM,        RangedValidator<GalaxySetupOption>(GALAXY_SETUP_NONE, GALAXY_SETUP_RANDOM));
         db.Add("setup.empire.name",             UserStringNop("OPTIONS_DB_GAMESETUP_EMPIRE_NAME"),              std::string(""),            Validator<std::string>());
         db.Add("setup.player.name",             UserStringNop("OPTIONS_DB_GAMESETUP_PLAYER_NAME"),              std::string(""),            Validator<std::string>());
         db.Add("setup.empire.color.index",      UserStringNop("OPTIONS_DB_GAMESETUP_EMPIRE_COLOR"),             9,                          RangedValidator<int>(0, 100));
         db.Add("setup.initial.species",         UserStringNop("OPTIONS_DB_GAMESETUP_STARTING_SPECIES_NAME"),    std::string("SP_HUMAN"),    Validator<std::string>());
-        db.Add("setup.ai.player.count",         UserStringNop("OPTIONS_DB_GAMESETUP_NUM_AI_PLAYERS"),           6,                          RangedValidator<int>(0, IApp::MAX_AI_PLAYERS()));
-        db.Add("setup.ai.aggression",           UserStringNop("OPTIONS_DB_GAMESETUP_AI_MAX_AGGRESSION"),        MANIACAL,                   RangedValidator<Aggression>(BEGINNER, MANIACAL));
     }
     bool temp_bool = RegisterOptions(&AddOptions);
 }
@@ -177,6 +163,9 @@ GameRulesPanel::GameRulesPanel(GG::X w, GG::Y h) :
 {}
 
 void GameRulesPanel::CompleteConstruction() {
+    GG::Control::CompleteConstruction();
+    DebugLogger() << "GalaxySetupPanel::CompleteConstruction";
+
     m_tabs = GG::Wnd::Create<GG::TabWnd>(GG::X0, GG::Y0, SPIN_WIDTH, GG::Y1,
                                          ClientUI::GetFont(), ClientUI::WndColor(), ClientUI::TextColor());
     AttachChild(m_tabs);
@@ -200,17 +189,17 @@ void GameRulesPanel::CompleteConstruction() {
         auto current_page = itr->second;
 
         // add rule to page
-        switch (rule.second.rule_type) {
-        case GameRules::TOGGLE:
+        switch (rule.second.type) {
+        case GameRules::Type::TOGGLE:
             BoolRuleWidget(current_page, 0, rule.first);
             break;
-        case GameRules::INT:
+        case GameRules::Type::INT:
             IntRuleWidget(current_page, 0, rule.first);
             break;
-        case GameRules::DOUBLE:
+        case GameRules::Type::DOUBLE:
             DoubleRuleWidget(current_page, 0, rule.first);
             break;
-        case GameRules::STRING:
+        case GameRules::Type::STRING:
             StringRuleWidget(current_page, 0, rule.first);
             break;
         default:
@@ -222,10 +211,10 @@ void GameRulesPanel::CompleteConstruction() {
     m_tabs->SetCurrentWnd(0);
 }
 
-std::vector<std::pair<std::string, std::string>> GameRulesPanel::GetRulesAsStrings() const {
-    std::vector<std::pair<std::string, std::string>> retval;
+std::map<std::string, std::string> GameRulesPanel::GetRulesAsStrings() const {
+    std::map<std::string, std::string> retval;
     for (const auto& entry : m_rules)
-        retval.push_back(entry);
+        retval.insert(entry);
     return retval;
 }
 
@@ -404,8 +393,10 @@ namespace {
     // row type used in the SpeciesSelector
     struct UserStringRow : public GG::ListBox::Row {
         UserStringRow(const std::string& key, GG::X w, GG::Y h) :
-            GG::ListBox::Row(w, h, "", GG::ALIGN_VCENTER, 0)
+            GG::ListBox::Row(w, h)
         {
+            SetMargin(0);
+            SetRowAlignment(GG::ALIGN_VCENTER);
             GG::Wnd::SetName(key);
         }
 
@@ -413,6 +404,7 @@ namespace {
             GG::ListBox::Row::CompleteConstruction();
             auto species_label = GG::Wnd::Create<CUILabel>(UserString(Name()), GG::FORMAT_LEFT | GG::FORMAT_VCENTER);
             push_back(species_label);
+            SetChildClippingMode(ClipToClient);
         }
     };
 }
@@ -428,9 +420,7 @@ GG::DropDownList* GameRulesPanel::StringRuleWidget(GG::ListBox* page, int indent
     auto drop = GG::Wnd::Create<CUIDropDownList>(5);
     drop->Resize(GG::Pt(SPIN_WIDTH, drop->MinUsableSize().y));
 
-    if (auto desc_val =
-        std::dynamic_pointer_cast<const DiscreteValidator<std::string>>(validator))
-    {
+    if (auto desc_val = std::dynamic_pointer_cast<const DiscreteValidator<std::string>>(validator)) {
         // add rows for all allowed options
         for (auto& poss : desc_val->m_values)
             drop->Insert(GG::Wnd::Create<UserStringRow>(poss, drop->Width(), drop->Height() - 4));
@@ -447,7 +437,7 @@ GG::DropDownList* GameRulesPanel::StringRuleWidget(GG::ListBox* page, int indent
     }
 
 
-    auto layout = GG::Wnd::Create<GG::Layout>(GG::X0, GG::Y0, Width(), drop->MinUsableSize().y, 1, 2, 0, 5);
+    auto layout = GG::Wnd::Create<GG::Layout>(GG::X0, GG::Y0, Width(), drop->MinUsableSize().y, 1, 2, 1, 5);
     layout->Add(drop, 0, 0, GG::ALIGN_VCENTER | GG::ALIGN_LEFT);
     layout->Add(text_control, 0, 1, GG::ALIGN_VCENTER | GG::ALIGN_LEFT);
     layout->SetMinimumColumnWidth(0, SPIN_WIDTH);
@@ -549,20 +539,23 @@ GalaxySetupPanel::GalaxySetupPanel(GG::X w, GG::Y h) :
 
 void GalaxySetupPanel::CompleteConstruction() {
     GG::Control::CompleteConstruction();
-
+    DebugLogger() << "GalaxySetupPanel::CompleteConstruction";
     Sound::TempUISoundDisabler sound_disabler;
 
     // seed
     m_seed_label = GG::Wnd::Create<CUILabel>(UserString("GSETUP_SEED"), GG::FORMAT_RIGHT, GG::INTERACTIVE);
     m_seed_label->SetBrowseModeTime(GetOptionsDB().Get<int>("ui.tooltip.delay"));
+    TraceLogger() << "GalaxySetupPanel::CompleteConstruction attempting to access common galaxy settings from OptionsDB";
     m_seed_label->SetBrowseText(UserString(GetOptionsDB().GetDescription("setup.seed")));
     m_seed = GetOptionsDB().Get<std::string>("setup.seed");
+    TraceLogger() << "GalaxySetupPanel::CompleteConstruction got seed and seed label";
     if (m_seed == "RANDOM" || m_seed.empty()) {
         m_seed = "RANDOM";
         m_seed_edit = GG::Wnd::Create<CUIEdit>(UserString("GSETUP_RANDOM"));
     } else {
         m_seed_edit = GG::Wnd::Create<CUIEdit>(m_seed);
     }
+    m_seed_edit->DisallowChars("<>/\\[]'`?{}, ");
 
     boost::filesystem::path button_texture_dir = ClientUI::ArtDir() / "icons" / "buttons";
 
@@ -659,32 +652,24 @@ void GalaxySetupPanel::CompleteConstruction() {
     AttachChild(m_ai_aggression_label);
     AttachChild(m_ai_aggression_list);
 
+    TraceLogger() << "GalaxySetupPanel::CompleteConstruction layout";
     DoLayout();
 
-    m_random->LeftClickedSignal.connect(
-        boost::bind(&GalaxySetupPanel::RandomClicked, this));
-    m_seed_edit->FocusUpdateSignal.connect(
-        boost::bind(&GalaxySetupPanel::SetSeed, this, _1, false));
-    m_stars_spin->ValueChangedSignal.connect(
-        boost::bind(&GalaxySetupPanel::SettingChanged, this));
-    m_galaxy_shapes_list->SelChangedSignal.connect(
-        boost::bind(&GalaxySetupPanel::SettingChanged, this));
-    m_galaxy_ages_list->SelChangedSignal.connect(
-        boost::bind(&GalaxySetupPanel::SettingChanged, this));
-    m_starlane_freq_list->SelChangedSignal.connect(
-        boost::bind(&GalaxySetupPanel::SettingChanged, this));
-    m_planet_density_list->SelChangedSignal.connect(
-        boost::bind(&GalaxySetupPanel::SettingChanged, this));
-    m_specials_freq_list->SelChangedSignal.connect(
-        boost::bind(&GalaxySetupPanel::SettingChanged, this));
-    m_monster_freq_list->SelChangedSignal.connect(
-        boost::bind(&GalaxySetupPanel::SettingChanged, this));
-    m_native_freq_list->SelChangedSignal.connect(
-        boost::bind(&GalaxySetupPanel::SettingChanged, this));
-    m_ai_aggression_list->SelChangedSignal.connect(
-        boost::bind(&GalaxySetupPanel::SettingChanged, this));
-    m_galaxy_shapes_list->SelChangedSignal.connect(
-        boost::bind(&GalaxySetupPanel::ShapeChanged, this, _1));
+    using boost::placeholders::_1;
+
+    TraceLogger() << "GalaxySetupPanel::CompleteConstruction connecting signals and loading textures";
+    m_random->LeftClickedSignal.connect(            boost::bind(&GalaxySetupPanel::RandomClicked, this));
+    m_seed_edit->FocusUpdateSignal.connect(         boost::bind(&GalaxySetupPanel::SetSeed, this, _1, false));
+    m_stars_spin->ValueChangedSignal.connect(       boost::bind(&GalaxySetupPanel::SettingChanged, this));
+    m_galaxy_shapes_list->SelChangedSignal.connect( boost::bind(&GalaxySetupPanel::SettingChanged, this));
+    m_galaxy_ages_list->SelChangedSignal.connect(   boost::bind(&GalaxySetupPanel::SettingChanged, this));
+    m_starlane_freq_list->SelChangedSignal.connect( boost::bind(&GalaxySetupPanel::SettingChanged, this));
+    m_planet_density_list->SelChangedSignal.connect(boost::bind(&GalaxySetupPanel::SettingChanged, this));
+    m_specials_freq_list->SelChangedSignal.connect( boost::bind(&GalaxySetupPanel::SettingChanged, this));
+    m_monster_freq_list->SelChangedSignal.connect(  boost::bind(&GalaxySetupPanel::SettingChanged, this));
+    m_native_freq_list->SelChangedSignal.connect(   boost::bind(&GalaxySetupPanel::SettingChanged, this));
+    m_ai_aggression_list->SelChangedSignal.connect( boost::bind(&GalaxySetupPanel::SettingChanged, this));
+    m_galaxy_shapes_list->SelChangedSignal.connect( boost::bind(&GalaxySetupPanel::ShapeChanged, this, _1));
 
     // create and load textures
     m_textures.clear();
@@ -701,6 +686,7 @@ void GalaxySetupPanel::CompleteConstruction() {
     m_textures[RANDOM] =      ClientUI::GetTexture(ClientUI::ArtDir() / "gp_random.png");
 
     // fill droplists
+    TraceLogger() << "GalaxySetupPanel::CompleteConstruction filling droplists";
     m_galaxy_shapes_list->Insert(GG::Wnd::Create<CUISimpleDropDownListRow>(UserString("GSETUP_2ARM")));
     m_galaxy_shapes_list->Insert(GG::Wnd::Create<CUISimpleDropDownListRow>(UserString("GSETUP_3ARM")));
     m_galaxy_shapes_list->Insert(GG::Wnd::Create<CUISimpleDropDownListRow>(UserString("GSETUP_4ARM")));
@@ -717,8 +703,6 @@ void GalaxySetupPanel::CompleteConstruction() {
     m_galaxy_ages_list->Insert(GG::Wnd::Create<CUISimpleDropDownListRow>(UserString("GSETUP_ANCIENT")));
     m_galaxy_ages_list->Insert(GG::Wnd::Create<CUISimpleDropDownListRow>(UserString("GSETUP_RANDOM")));
 
-    if (ALLOW_NO_STARLANES)
-        m_starlane_freq_list->Insert(GG::Wnd::Create<CUISimpleDropDownListRow>(UserString("GSETUP_NONE")));
     m_starlane_freq_list->Insert(GG::Wnd::Create<CUISimpleDropDownListRow>(UserString("GSETUP_LOW")));
     m_starlane_freq_list->Insert(GG::Wnd::Create<CUISimpleDropDownListRow>(UserString("GSETUP_MEDIUM")));
     m_starlane_freq_list->Insert(GG::Wnd::Create<CUISimpleDropDownListRow>(UserString("GSETUP_HIGH")));
@@ -755,20 +739,24 @@ void GalaxySetupPanel::CompleteConstruction() {
     m_ai_aggression_list->Insert(GG::Wnd::Create<CUISimpleDropDownListRow>(UserString("GSETUP_MANIACAL")));
 
     // initial settings from stored results or defaults
+    TraceLogger() << "GalaxySetupPanel::CompleteConstruction selecting stored settings or defaults";
+
     SetSeed(GetOptionsDB().Get<std::string>("setup.seed"), true);
     m_seed_edit->Disable(GetSeed() == "RANDOM");
     m_stars_spin->SetValue(GetOptionsDB().Get<int>("setup.star.count"));
     m_galaxy_shapes_list->Select(GetOptionsDB().Get<Shape>("setup.galaxy.shape"));
     ShapeChanged(m_galaxy_shapes_list->CurrentItem());
     m_galaxy_ages_list->Select(GetOptionsDB().Get<GalaxySetupOption>("setup.galaxy.age") - 1);
-    m_starlane_freq_list->Select(GetOptionsDB().Get<GalaxySetupOption>("setup.starlane.frequency") - (ALLOW_NO_STARLANES ? 0 : 1));
+    m_starlane_freq_list->Select(GetOptionsDB().Get<GalaxySetupOption>("setup.starlane.frequency") - 1);
     m_planet_density_list->Select(GetOptionsDB().Get<GalaxySetupOption>("setup.planet.density") - 1);
     m_specials_freq_list->Select(GetOptionsDB().Get<GalaxySetupOption>("setup.specials.frequency"));
     m_monster_freq_list->Select(GetOptionsDB().Get<GalaxySetupOption>("setup.monster.frequency"));
     m_native_freq_list->Select(GetOptionsDB().Get<GalaxySetupOption>("setup.native.frequency"));
     m_ai_aggression_list->Select(GetOptionsDB().Get<Aggression>("setup.ai.aggression"));
 
+    TraceLogger() << "GalaxySetupPanel::CompleteConstruction settings changed signal...";
     SettingsChangedSignal();
+    TraceLogger() << "GalaxySetupPanel::CompleteConstruction done";
 }
 
 void GalaxySetupPanel::RandomClicked() {
@@ -806,7 +794,7 @@ GalaxySetupOption GalaxySetupPanel::GetAge() const
 { return GalaxySetupOption(m_galaxy_ages_list->CurrentItemIndex() + 1); }
 
 GalaxySetupOption GalaxySetupPanel::GetStarlaneFrequency() const
-{ return GalaxySetupOption(m_starlane_freq_list->CurrentItemIndex() + (ALLOW_NO_STARLANES ? 0 : 1)); }
+{ return GalaxySetupOption(m_starlane_freq_list->CurrentItemIndex() + 1); }
 
 GalaxySetupOption GalaxySetupPanel::GetPlanetDensity() const
 { return GalaxySetupOption(m_planet_density_list->CurrentItemIndex() + 1); }
@@ -934,7 +922,7 @@ void GalaxySetupPanel::SetFromSetupData(const GalaxySetupData& setup_data) {
     m_galaxy_shapes_list->Select(setup_data.m_shape);
     ShapeChanged(m_galaxy_shapes_list->CurrentItem());
     m_galaxy_ages_list->Select(setup_data.m_age - 1);
-    m_starlane_freq_list->Select(setup_data.m_starlane_freq - (ALLOW_NO_STARLANES ? 0 : 1));
+    m_starlane_freq_list->Select(setup_data.m_starlane_freq - 1);
     m_planet_density_list->Select(setup_data.m_planet_density - 1);
     m_specials_freq_list->Select(setup_data.m_specials_freq);
     m_monster_freq_list->Select(setup_data.m_monster_freq);
@@ -968,14 +956,26 @@ void GalaxySetupPanel::ShapeChanged(GG::DropDownList::iterator it)
 // GalaxySetupWnd
 ////////////////////////////////////////////////
 GalaxySetupWnd::GalaxySetupWnd() :
-    CUIWnd(UserString("GSETUP_WINDOW_TITLE"), GG::INTERACTIVE | GG::MODAL)
+    CUIWnd(UserString("GSETUP_WINDOW_TITLE"), GG::INTERACTIVE | GG::MODAL | GG::DRAGABLE /*| GG::RESIZABLE*/)
 {}
 
 void GalaxySetupWnd::CompleteConstruction() {
     Sound::TempUISoundDisabler sound_disabler;
 
-    m_galaxy_setup_panel = GG::Wnd::Create<GalaxySetupPanel>();
-    m_game_rules_panel = GG::Wnd::Create<GameRulesPanel>();
+    DebugLogger() << "GalaxySetupWnd::CompleteConstruction";
+
+    try {
+        m_galaxy_setup_panel = GG::Wnd::Create<GalaxySetupPanel>();
+    } catch (const boost::bad_any_cast& e) {
+        ErrorLogger() << "bad any cast creating galaxy setup panel: " << e.what();
+        throw;
+    }
+    try {
+        m_game_rules_panel = GG::Wnd::Create<GameRulesPanel>();
+    } catch (const boost::bad_any_cast& e) {
+        ErrorLogger() << "bad any cast creating game rules panel: " << e.what();
+        throw;
+    }
 
     const GG::X LABELS_WIDTH = (GalaxySetupPanel::DefaultWidth() - 5) / 2;
 
@@ -1046,16 +1046,13 @@ void GalaxySetupWnd::CompleteConstruction() {
     DoLayout();
     SaveDefaultedOptions();
 
-    m_galaxy_setup_panel->ImageChangedSignal.connect(
-        boost::bind(&GalaxySetupWnd::PreviewImageChanged, this, _1));
-    m_player_name_edit->EditedSignal.connect(
-        boost::bind(&GalaxySetupWnd::PlayerNameChanged, this, _1));
-    m_empire_name_edit->EditedSignal.connect(
-        boost::bind(&GalaxySetupWnd::EmpireNameChanged, this, _1));
-    m_ok->LeftClickedSignal.connect(
-        boost::bind(&GalaxySetupWnd::OkClicked, this));
-    m_cancel->LeftClickedSignal.connect(
-        boost::bind(&GalaxySetupWnd::CancelClicked, this));
+    using boost::placeholders::_1;
+
+    m_galaxy_setup_panel->ImageChangedSignal.connect(boost::bind(&GalaxySetupWnd::PreviewImageChanged,  this, _1));
+    m_player_name_edit->EditedSignal.connect(        boost::bind(&GalaxySetupWnd::PlayerNameChanged,    this, _1));
+    m_empire_name_edit->EditedSignal.connect(        boost::bind(&GalaxySetupWnd::EmpireNameChanged,    this, _1));
+    m_ok->LeftClickedSignal.connect(                 boost::bind(&GalaxySetupWnd::OkClicked,            this));
+    m_cancel->LeftClickedSignal.connect(             boost::bind(&GalaxySetupWnd::CancelClicked,        this));
 
     PreviewImageChanged(m_galaxy_setup_panel->PreviewImage());
 
@@ -1074,7 +1071,7 @@ const std::string& GalaxySetupWnd::StartingSpeciesName() const
 int GalaxySetupWnd::NumberAIs() const
 { return m_number_ais_spin->Value(); }
 
-std::vector<std::pair<std::string, std::string>> GalaxySetupWnd::GetRulesAsStrings() const
+std::map<std::string, std::string> GalaxySetupWnd::GetRulesAsStrings() const
 { return m_game_rules_panel->GetRulesAsStrings(); }
 
 void GalaxySetupWnd::Render() {
@@ -1087,9 +1084,8 @@ void GalaxySetupWnd::Render() {
 }
 
 void GalaxySetupWnd::KeyPress(GG::Key key, std::uint32_t key_code_point, GG::Flags<GG::ModKey> mod_keys) {
-    if (!m_ok->Disabled() && (key == GG::GGK_RETURN || key == GG::GGK_KP_ENTER)) // Same behaviour as if "OK" was pressed
-        OkClicked();
-    else if (key == GG::GGK_ESCAPE) // Same behaviour as if "Cancel" was pressed
+    // Enter is no longer accepted as OK as it could clash with ALT-Enter
+    if (key == GG::GGK_ESCAPE) // Same behaviour as if "Cancel" was pressed
         CancelClicked();
 }
 
@@ -1185,23 +1181,90 @@ void GalaxySetupWnd::PlayerNameChanged(const std::string& name)
 { m_ok->Disable(name.empty()); }
 
 void GalaxySetupWnd::OkClicked() {
+    TraceLogger() << "GalaxySetupWnd::OkClicked start";
     // record selected galaxy setup options as new defaults
-    GetOptionsDB().Set("setup.seed", m_galaxy_setup_panel->GetSeed());
-    GetOptionsDB().Set("setup.star.count", m_galaxy_setup_panel->Systems());
-    GetOptionsDB().Set("setup.galaxy.shape", m_galaxy_setup_panel->GetShape());
-    GetOptionsDB().Set("setup.galaxy.age", m_galaxy_setup_panel->GetAge());
-    GetOptionsDB().Set("setup.starlane.frequency", m_galaxy_setup_panel->GetStarlaneFrequency());
-    GetOptionsDB().Set("setup.planet.density", m_galaxy_setup_panel->GetPlanetDensity());
-    GetOptionsDB().Set("setup.specials.frequency", m_galaxy_setup_panel->GetSpecialsFrequency());
-    GetOptionsDB().Set("setup.monster.frequency", m_galaxy_setup_panel->GetMonsterFrequency());
-    GetOptionsDB().Set("setup.native.frequency", m_galaxy_setup_panel->GetNativeFrequency());
-    GetOptionsDB().Set("setup.ai.aggression", m_galaxy_setup_panel->GetAIAggression());
-    GetOptionsDB().Set("setup.player.name", m_player_name_edit->Text());
-    GetOptionsDB().Set("setup.empire.name", EmpireName());
-    GetOptionsDB().Set("setup.empire.color.index", static_cast<int>(m_empire_color_selector->CurrentItemIndex()));
-    GetOptionsDB().Set("setup.initial.species", m_starting_secies_selector->CurrentSpeciesName());
-    GetOptionsDB().Set("setup.ai.player.count", m_number_ais_spin->Value());
-    GetOptionsDB().Commit();
+    try {
+        GetOptionsDB().Set("setup.seed",                m_galaxy_setup_panel->GetSeed());
+    } catch (const std::exception& e) {
+        ErrorLogger() << "Caught exception setting setup seed from setup panel results: " << e.what();
+    }
+    try {
+        GetOptionsDB().Set("setup.star.count",          m_galaxy_setup_panel->Systems());
+    } catch (const std::exception& e) {
+        ErrorLogger() << "Caught exception setting star count from setup panel results: " << e.what();
+    }
+    try {
+        GetOptionsDB().Set("setup.galaxy.shape",        m_galaxy_setup_panel->GetShape());
+    } catch (const std::exception& e) {
+        ErrorLogger() << "Caught exception setting galaxy shape from setup panel results: " << e.what();
+    }
+    try {
+        GetOptionsDB().Set("setup.galaxy.age",          m_galaxy_setup_panel->GetAge());
+    } catch (const std::exception& e) {
+        ErrorLogger() << "Caught exception setting galaxy age from setup panel results: " << e.what();
+    }
+    try {
+        GetOptionsDB().Set("setup.starlane.frequency",  m_galaxy_setup_panel->GetStarlaneFrequency());
+    } catch (const std::exception& e) {
+        ErrorLogger() << "Caught exception setting starlane frequency from setup panel results: " << e.what();
+    }
+    try {
+        GetOptionsDB().Set("setup.planet.density",      m_galaxy_setup_panel->GetPlanetDensity());
+    } catch (const std::exception& e) {
+        ErrorLogger() << "Caught exception setting planet density from setup panel results: " << e.what();
+    }
+    try {
+        GetOptionsDB().Set("setup.specials.frequency",  m_galaxy_setup_panel->GetSpecialsFrequency());
+    } catch (const std::exception& e) {
+        ErrorLogger() << "Caught exception setting special frequency from setup panel results: " << e.what();
+    }
+    try {
+        GetOptionsDB().Set("setup.monster.frequency",   m_galaxy_setup_panel->GetMonsterFrequency());
+    } catch (const std::exception& e) {
+        ErrorLogger() << "Caught exception setting monster frequency from setup panel results: " << e.what();
+    }
+    try {
+        GetOptionsDB().Set("setup.native.frequency",    m_galaxy_setup_panel->GetNativeFrequency());
+    } catch (const std::exception& e) {
+        ErrorLogger() << "Caught exception setting native frequency from setup panel results: " << e.what();
+    }
+    try {
+        GetOptionsDB().Set("setup.ai.aggression",       m_galaxy_setup_panel->GetAIAggression());
+    } catch (const std::exception& e) {
+        ErrorLogger() << "Caught exception setting ai aggression from setup panel results: " << e.what();
+    }
+    try {
+        GetOptionsDB().Set("setup.player.name",         m_player_name_edit->Text());
+    } catch (const std::exception& e) {
+        ErrorLogger() << "Caught exception setting player name from setup panel results: " << e.what();
+    }
+    try {
+        GetOptionsDB().Set("setup.empire.name",         EmpireName());
+    } catch (const std::exception& e) {
+        ErrorLogger() << "Caught exception setting empire name from setup panel results: " << e.what();
+    }
+    try {
+        GetOptionsDB().Set("setup.empire.color.index",  static_cast<int>(m_empire_color_selector->CurrentItemIndex()));
+    } catch (const std::exception& e) {
+        ErrorLogger() << "Caught exception setting color from setup panel results: " << e.what();
+    }
+    try {
+        GetOptionsDB().Set("setup.initial.species",     m_starting_secies_selector->CurrentSpeciesName());
+    } catch (const std::exception& e) {
+        ErrorLogger() << "Caught exception setting species from setup panel results: " << e.what();
+    }
+    try {
+        GetOptionsDB().Set("setup.ai.player.count",     m_number_ais_spin->Value());
+    } catch (const std::exception& e) {
+        ErrorLogger() << "Caught exception setting player count from setup panel results: " << e.what();
+    }
+    try {
+        GetOptionsDB().Commit();
+    } catch (const std::exception& e) {
+        ErrorLogger() << "Caught exception committing options from panel results: " << e.what();
+    }
+
+    TraceLogger() << "GalaxySetupWnd::OkClicked end";
 
     m_ended_with_ok = true;
     m_done = true;
