@@ -13,11 +13,10 @@
 #include "../util/i18n.h"
 #include "../util/Order.h"
 #include "../util/ScopedTimer.h"
-#include "../universe/Building.h"
+#include "../universe/BuildingType.h"
 #include "../universe/ShipDesign.h"
 #include "../universe/Enums.h"
 
-#include <GG/DrawUtil.h>
 #include <GG/Layout.h>
 #include <GG/StaticGraphic.h>
 
@@ -36,7 +35,7 @@ namespace {
         // queue width used also on research screen. prevent double-adding...
         if (!db.OptionExists("ui.queue.width"))
             db.Add("ui.queue.width", UserStringNop("OPTIONS_DB_UI_QUEUE_WIDTH"), 350, RangedValidator<int>(200, 500));
-        db.Add("ui.queue.production_location.shown", UserStringNop("OPTIONS_DB_UI_PROD_QUEUE_LOCATION"), true, Validator<bool>());
+        db.Add("ui.queue.production_location.shown", UserStringNop("OPTIONS_DB_UI_PROD_QUEUE_LOCATION"), true);
     }
     bool temp_bool = RegisterOptions(&AddOptions);
 
@@ -49,7 +48,7 @@ namespace {
                    GG::Y h, bool inProgress, bool amBlockType) :
             Control(GG::X0, GG::Y0, nwidth, h, GG::NO_WND_FLAGS)
         {
-            GG::Clr txtClr = inProgress ? GG::LightColor(ClientUI::ResearchableTechTextAndBorderColor()) : ClientUI::ResearchableTechTextAndBorderColor();
+            GG::Clr txtClr = inProgress ? GG::LightenClr(ClientUI::ResearchableTechTextAndBorderColor()) : ClientUI::ResearchableTechTextAndBorderColor();
             std::string nameText;
             if (amBlockType)
                 nameText = boost::io::str(FlexibleFormat(UserString("PRODUCTION_QUEUE_MULTIPLES")) % quantity);
@@ -122,9 +121,9 @@ namespace {
 
             DisableDropArrow();
             SetStyle(GG::LIST_LEFT | GG::LIST_NOSORT);
-            SetColor(inProgress ? GG::LightColor(ClientUI::ResearchableTechTextAndBorderColor())
+            SetColor(inProgress ? GG::LightenClr(ClientUI::ResearchableTechTextAndBorderColor())
                                 : ClientUI::ResearchableTechTextAndBorderColor());
-            SetInteriorColor(inProgress ? GG::LightColor(ClientUI::ResearchableTechFillColor())
+            SetInteriorColor(inProgress ? GG::LightenClr(ClientUI::ResearchableTechFillColor())
                                         : ClientUI::ResearchableTechFillColor());
             SetNumCols(1);
 
@@ -150,7 +149,7 @@ namespace {
             }
 
             this->SelChangedSignal.connect(
-                boost::bind(&QuantitySelector::SelectionChanged, this, _1));
+                boost::bind(&QuantitySelector::SelectionChanged, this, boost::placeholders::_1));
         }
 
         void SelectionChanged(GG::DropDownList::iterator it) {
@@ -199,34 +198,32 @@ namespace {
         void PreRender() override;
         void Render() override;
         void SizeMove(const GG::Pt& ul, const GG::Pt& lr) override;
+        void ItemQuantityChanged(int quant, int blocksize);
+        void ItemBlocksizeChanged(int quant, int blocksize);
 
-        void            UpdateQueue();
-        void            ItemQuantityChanged(int quant, int blocksize);
-        void            ItemBlocksizeChanged(int quant, int blocksize);
+        static GG::Y DefaultHeight();
 
-        static GG::Y    DefaultHeight();
-
-        mutable boost::signals2::signal<void(int,int)>    PanelUpdateQuantSignal;
+        mutable boost::signals2::signal<void(int,int)> PanelUpdateQuantSignal;
 
     private:
-        void            Draw(GG::Clr clr, bool fill);
-        void            DoLayout();
+        void Draw(GG::Clr clr, bool fill);
+        void DoLayout();
 
-        const ProductionQueue::Element  elem;
-        std::shared_ptr<GG::Label>                      m_name_text;
-        std::shared_ptr<GG::Label>                      m_location_text;
-        std::shared_ptr<GG::Label>                      m_PPs_and_turns_text;
-        std::shared_ptr<GG::Label>                      m_turns_remaining_until_next_complete_text;
-        std::shared_ptr<GG::StaticGraphic>              m_icon;
-        std::shared_ptr<MultiTurnProgressBar>           m_progress_bar;
-        std::shared_ptr<QuantitySelector>               m_quantity_selector;
-        std::shared_ptr<QuantitySelector>               m_block_size_selector;
-        bool                            m_in_progress;
-        int                             m_total_turns;
-        double                          m_turn_spending;
-        double                          m_total_cost;
-        double                          m_completed_progress;
-        bool                            m_order_issuing_enabled;
+        const ProductionQueue::Element          elem;
+        std::shared_ptr<GG::Label>              m_name_text;
+        std::shared_ptr<GG::Label>              m_location_text;
+        std::shared_ptr<GG::Label>              m_PPs_and_turns_text;
+        std::shared_ptr<GG::Label>              m_turns_remaining_until_next_complete_text;
+        std::shared_ptr<GG::StaticGraphic>      m_icon;
+        std::shared_ptr<MultiTurnProgressBar>   m_progress_bar;
+        std::shared_ptr<QuantitySelector>       m_quantity_selector;
+        std::shared_ptr<QuantitySelector>       m_block_size_selector;
+        bool                                    m_in_progress = false;
+        int                                     m_total_turns = 0;
+        double                                  m_turn_spending = 0.0;
+        double                                  m_total_cost = 0.0;
+        double                                  m_completed_progress = 0.0;
+        bool                                    m_order_issuing_enabled = true;
     };
 
     /////////////////////////////
@@ -276,7 +273,7 @@ namespace {
             main_text += UserString("BUILD_ITEM_TYPE_PROJECT") + "\n";
 
             item_name = UserString(elem.item.name);
-            auto loc = GetUniverseObject(elem.location);
+            auto loc = Objects().get(elem.location);
             location_ok = loc && loc->OwnedBy(elem.empire_id) && (std::dynamic_pointer_cast<const ResourceCenter>(loc));
 
             total_cost = 1.0;
@@ -284,12 +281,12 @@ namespace {
             icon = ClientUI::MeterIcon(METER_STOCKPILE);
         }
 
-        if (std::shared_ptr<UniverseObject> rally_object = GetUniverseObject(elem.rally_point_id)) {
+        if (auto rally_object = Objects().get(elem.rally_point_id)) {
             main_text += boost::io::str(FlexibleFormat(UserString("PRODUCTION_QUEUE_RALLIED_TO"))
                                         % rally_object->Name()) + "\n";
         }
 
-        if (std::shared_ptr<UniverseObject> location = GetUniverseObject(elem.location))
+        if (auto location = Objects().get(elem.location))
             main_text += boost::io::str(FlexibleFormat(UserString("PRODUCTION_QUEUE_ENQUEUED_ITEM_LOCATION"))
                                         % location->Name()) + "\n";
 
@@ -333,12 +330,11 @@ namespace {
 
     struct QueueRow : GG::ListBox::Row {
         QueueRow(GG::X w, const ProductionQueue::Element& elem_, int queue_index_) :
-            GG::ListBox::Row(w, QueueProductionItemPanel::DefaultHeight(),
-                             BuildDesignatorWnd::PRODUCTION_ITEM_DROP_TYPE),
-            panel(nullptr),
+            GG::ListBox::Row(w, QueueProductionItemPanel::DefaultHeight()),
             queue_index(queue_index_),
             elem(elem_)
         {
+            SetDragDropDataType(BuildDesignatorWnd::PRODUCTION_ITEM_DROP_TYPE);
             const Empire* empire = GetEmpire(HumanClientApp::GetApp()->EmpireID());
             float total_cost(1.0f);
             int minimum_turns(1);
@@ -359,8 +355,10 @@ namespace {
             SetBrowseModeTime(GetOptionsDB().Get<int>("ui.tooltip.delay"));
             SetBrowseInfoWnd(ProductionItemBrowseWnd(elem));
 
+            namespace ph = boost::placeholders;
+
             panel->PanelUpdateQuantSignal.connect(
-                boost::bind(&QueueRow::RowQuantChanged, this, _1, _2));
+                boost::bind(&QueueRow::RowQuantChanged, this, ph::_1, ph::_2));
 
             RequirePreRender();
         }
@@ -393,29 +391,20 @@ namespace {
             RowQuantChangedSignal(queue_index, quantity, blocksize);
         }
 
-        std::shared_ptr<QueueProductionItemPanel>                           panel;
+        std::shared_ptr<QueueProductionItemPanel>           panel;
         const int                                           queue_index;
         const ProductionQueue::Element                      elem;
         mutable boost::signals2::signal<void (int,int,int)> RowQuantChangedSignal;
-
     };
 
     //////////////////////////////////////////////////
     // QueueProductionItemPanel implementation
     //////////////////////////////////////////////////
-    QueueProductionItemPanel::QueueProductionItemPanel(GG::X x, GG::Y y, GG::X w, const ProductionQueue::Element& build,
-                                                       double turn_spending, double total_cost, int turns, int number,
-                                                       double completed_progress) :
+    QueueProductionItemPanel::QueueProductionItemPanel(
+        GG::X x, GG::Y y, GG::X w, const ProductionQueue::Element& build,
+        double turn_spending, double total_cost, int turns, int number, double completed_progress) :
         GG::Control(x, y, w, DefaultHeight(), GG::NO_WND_FLAGS),
         elem(build),
-        m_name_text(nullptr),
-        m_location_text(nullptr),
-        m_PPs_and_turns_text(nullptr),
-        m_turns_remaining_until_next_complete_text(nullptr),
-        m_icon(nullptr),
-        m_progress_bar(nullptr),
-        m_quantity_selector(nullptr),
-        m_block_size_selector(nullptr),
         m_in_progress(build.allocated_pp || build.turns_left_to_next_item == 1),
         m_total_turns(turns),
         m_turn_spending(turn_spending),
@@ -428,7 +417,7 @@ namespace {
         SetChildClippingMode(ClipToClient);
 
         GG::Clr clr = m_in_progress
-            ? GG::LightColor(ClientUI::ResearchableTechTextAndBorderColor())
+            ? GG::LightenClr(ClientUI::ResearchableTechTextAndBorderColor())
             : ClientUI::ResearchableTechTextAndBorderColor();
 
         // get graphic and player-visible name text for item
@@ -456,14 +445,15 @@ namespace {
         std::string location_text;
         bool system_selected = false;
         bool rally_dest_selected = (elem.rally_point_id != INVALID_OBJECT_ID && elem.rally_point_id == SidePanel::SystemID());
-        if (std::shared_ptr<const UniverseObject> location = GetUniverseObject(elem.location)) {
+        if (const auto location = Objects().get(elem.location)) {
             system_selected = (location->SystemID() != INVALID_OBJECT_ID && location ->SystemID() == SidePanel::SystemID());
             if (GetOptionsDB().Get<bool>("ui.queue.production_location.shown")) {
                 if (rally_dest_selected && !system_selected) {
                     location_text = boost::io::str(FlexibleFormat(UserString(
                         "PRODUCTION_QUEUE_ITEM_RALLIED_FROM_LOCATION")) % location->Name()) + " ";
                 } else {
-                    location_text = boost::io::str(FlexibleFormat(UserString("PRODUCTION_QUEUE_ITEM_LOCATION")) % location->Name()) + " ";
+                    location_text = boost::io::str(FlexibleFormat(UserString(
+                        "PRODUCTION_QUEUE_ITEM_LOCATION")) % location->Name()) + " ";
                 }
             }
         }
@@ -475,10 +465,10 @@ namespace {
             m_icon = GG::Wnd::Create<GG::StaticGraphic>(graphic, GG::GRAPHIC_FITGRAPHIC | GG::GRAPHIC_PROPSCALE);
 
         if (elem.item.build_type == BT_SHIP || elem.item.build_type == BT_STOCKPILE) {
-            m_quantity_selector = GG::Wnd::Create<QuantitySelector>(elem, GG::X1, GG::Y(MARGIN), GG::Y(FONT_PTS-2*MARGIN),
-                                                                    m_in_progress, GG::X(FONT_PTS*2.5), false);
-            m_block_size_selector = GG::Wnd::Create<QuantitySelector>(elem, GG::X1, GG::Y(MARGIN), GG::Y(FONT_PTS-2*MARGIN),
-                                                                      m_in_progress, GG::X(FONT_PTS*2.5), true);
+            m_quantity_selector = GG::Wnd::Create<QuantitySelector>(
+                elem, GG::X1, GG::Y(MARGIN), GG::Y(FONT_PTS-2*MARGIN), m_in_progress, GG::X(FONT_PTS*2.5), false);
+            m_block_size_selector = GG::Wnd::Create<QuantitySelector>(
+                elem, GG::X1, GG::Y(MARGIN), GG::Y(FONT_PTS-2*MARGIN), m_in_progress, GG::X(FONT_PTS*2.5), true);
             m_quantity_selector->SetOnlyMouseScrollWhenDropped(true);
             m_block_size_selector->SetOnlyMouseScrollWhenDropped(true);
         }
@@ -492,7 +482,7 @@ namespace {
         const Empire* this_client_empire = GetEmpire(client_empire_id);
         if (this_client_empire && (system_selected || rally_dest_selected)) {
             auto empire_color = this_client_empire->Color();
-            auto rally_color = GG::DarkColor(GG::Clr(255 - empire_color.r, 255 - empire_color.g, 255 - empire_color.b, empire_color.a));
+            auto rally_color = GG::DarkenClr(GG::InvertClr(empire_color));
             auto location_color = system_selected ? empire_color : rally_color;
             m_location_text = GG::Wnd::Create<GG::TextControl>(GG::X0, GG::Y0, GG::X1, GG::Y1, "<s>" + location_text + "</s>",
                                                   ClientUI::GetBoldFont(), location_color, GG::FORMAT_TOP | GG::FORMAT_RIGHT);
@@ -510,12 +500,12 @@ namespace {
 
         GG::Clr outline_color = ClientUI::ResearchableTechFillColor();
         if (m_in_progress)
-            outline_color = GG::LightColor(outline_color);
+            outline_color = GG::LightenClr(outline_color);
 
         m_progress_bar = GG::Wnd::Create<MultiTurnProgressBar>(m_total_turns,
                                                                perc_complete,
                                                                next_progress,
-                                                               GG::LightColor(ClientUI::TechWndProgressBarBackgroundColor()),
+                                                               GG::LightenClr(ClientUI::TechWndProgressBarBackgroundColor()),
                                                                ClientUI::TechWndProgressBarColor(),
                                                                outline_color);
 
@@ -546,12 +536,15 @@ namespace {
         AttachChild(m_PPs_and_turns_text);
         AttachChild(m_turns_remaining_until_next_complete_text);
         AttachChild(m_progress_bar);
+
+        namespace ph = boost::placeholders;
+
         if (m_quantity_selector)
             m_quantity_selector->QuantChangedSignal.connect(
-                boost::bind(&QueueProductionItemPanel::ItemQuantityChanged, this, _1, _2));
+                boost::bind(&QueueProductionItemPanel::ItemQuantityChanged, this, ph::_1, ph::_2));
         if (m_block_size_selector)
             m_block_size_selector->QuantChangedSignal.connect(
-                boost::bind(&QueueProductionItemPanel::ItemBlocksizeChanged, this, _1, _2));
+                boost::bind(&QueueProductionItemPanel::ItemBlocksizeChanged, this, ph::_1, ph::_2));
 
         RequirePreRender();
     }
@@ -622,17 +615,17 @@ namespace {
     }
 
     void QueueProductionItemPanel::ItemQuantityChanged(int quant, int blocksize)
-    { PanelUpdateQuantSignal(quant,elem.blocksize); }
+    { if (m_order_issuing_enabled) PanelUpdateQuantSignal(quant, elem.blocksize); }
 
-    void QueueProductionItemPanel::ItemBlocksizeChanged(int quant, int blocksize) // made separate funcion in case wna to do extra checking
-    { PanelUpdateQuantSignal(elem.remaining, blocksize); }
+    void QueueProductionItemPanel::ItemBlocksizeChanged(int quant, int blocksize)
+    { if (m_order_issuing_enabled) PanelUpdateQuantSignal(elem.remaining, blocksize); }
 
     void QueueProductionItemPanel::Render() {
         GG::Clr fill = m_in_progress
-            ? GG::LightColor(ClientUI::ResearchableTechFillColor())
+            ? GG::LightenClr(ClientUI::ResearchableTechFillColor())
             : ClientUI::ResearchableTechFillColor();
         GG::Clr text_and_border = m_in_progress
-            ? GG::LightColor(ClientUI::ResearchableTechTextAndBorderColor())
+            ? GG::LightenClr(ClientUI::ResearchableTechTextAndBorderColor())
             : ClientUI::ResearchableTechTextAndBorderColor();
 
         glDisable(GL_TEXTURE_2D);
@@ -663,12 +656,21 @@ namespace {
     class ProdQueueListBox : public QueueListBox {
     public:
         ProdQueueListBox() :
-            QueueListBox(BuildDesignatorWnd::PRODUCTION_ITEM_DROP_TYPE,  UserString("PRODUCTION_QUEUE_PROMPT"))
+            QueueListBox(BuildDesignatorWnd::PRODUCTION_ITEM_DROP_TYPE, UserString("PRODUCTION_QUEUE_PROMPT"))
         {}
 
         void CompleteConstruction() override
         { QueueListBox::CompleteConstruction(); }
 
+        void EnableOrderIssuing(bool enable = true) override {
+            QueueListBox::EnableOrderIssuing(enable);
+
+            for (auto it = this->begin(); it != this->end(); ++it) {
+                if (auto queue_row = std::dynamic_pointer_cast<QueueRow>(*it))
+                    queue_row->Disable(!enable);
+            }
+        }
+
         boost::signals2::signal<void (GG::ListBox::iterator, int)>  QueueItemRalliedToSignal;
         boost::signals2::signal<void ()>                            ShowPediaSignal;
         boost::signals2::signal<void (GG::ListBox::iterator, bool)> QueueItemPausedSignal;
@@ -695,9 +697,11 @@ namespace {
 
             auto popup = GG::Wnd::Create<CUIPopupMenu>(pt.x, pt.y);
 
-            popup->AddMenuItem(GG::MenuItem(UserString("MOVE_UP_QUEUE_ITEM"),   false, false, MoveToTopAction(it)));
-            popup->AddMenuItem(GG::MenuItem(UserString("MOVE_DOWN_QUEUE_ITEM"), false, false, MoveToBottomAction(it)));
-            popup->AddMenuItem(GG::MenuItem(UserString("DELETE_QUEUE_ITEM"),    false, false, DeleteAction(it)));
+            bool disabled = !OrderIssuingEnabled();
+
+            popup->AddMenuItem(GG::MenuItem(UserString("MOVE_UP_QUEUE_ITEM"),   disabled, false, MoveToTopAction(it)));
+            popup->AddMenuItem(GG::MenuItem(UserString("MOVE_DOWN_QUEUE_ITEM"), disabled, false, MoveToBottomAction(it)));
+            popup->AddMenuItem(GG::MenuItem(UserString("DELETE_QUEUE_ITEM"),    disabled, false, DeleteAction(it)));
 
             // inspect clicked item: was it a ship?
             auto& row = *it;
@@ -718,24 +722,24 @@ namespace {
                 return;
             }
 
-            popup->AddMenuItem(GG::MenuItem(UserString("DUPLICATE"), !location_passes, false, dupe_action));
+            popup->AddMenuItem(GG::MenuItem(UserString("DUPLICATE"), disabled || !location_passes, false, dupe_action));
             if (remaining > 1) {
-                popup->AddMenuItem(GG::MenuItem(UserString("SPLIT_INCOMPLETE"), false, false, split_action));
+                popup->AddMenuItem(GG::MenuItem(UserString("SPLIT_INCOMPLETE"), disabled, false, split_action));
             }
 
             if (build_type == BT_SHIP) {
                 // for ships, add a set rally point command
-                if (auto system = GetSystem(SidePanel::SystemID())) {
+                if (auto system = Objects().get<System>(SidePanel::SystemID())) {
                     std::string rally_prompt = boost::io::str(FlexibleFormat(UserString("RALLY_QUEUE_ITEM")) % system->PublicName(HumanClientApp::GetApp()->EmpireID()));
-                    popup->AddMenuItem(GG::MenuItem(rally_prompt,               false, false, rally_to_action));
+                    popup->AddMenuItem(GG::MenuItem(rally_prompt, disabled, false, rally_to_action));
                 }
             }
 
             // pause / resume commands
             if (queue_row && queue_row->elem.paused) {
-                popup->AddMenuItem(GG::MenuItem(UserString("RESUME"),           false, false, resume_action));
+                popup->AddMenuItem(GG::MenuItem(UserString("RESUME"), disabled, false, resume_action));
             } else {
-                popup->AddMenuItem(GG::MenuItem(UserString("PAUSE"),            false, false, pause_action));
+                popup->AddMenuItem(GG::MenuItem(UserString("PAUSE"), disabled, false, pause_action));
             }
 
             // stockpile use allow/disallow commands
@@ -743,16 +747,16 @@ namespace {
             case BT_BUILDING:
             case BT_SHIP:
                 if (queue_row && queue_row->elem.allowed_imperial_stockpile_use) {
-                    popup->AddMenuItem(GG::MenuItem(UserString("DISALLOW_IMPERIAL_PP_STOCKPILE_USE"), false, false, disallow_stockpile_action));
+                    popup->AddMenuItem(GG::MenuItem(UserString("DISALLOW_IMPERIAL_PP_STOCKPILE_USE"), disabled, false, disallow_stockpile_action));
                 } else {
-                    popup->AddMenuItem(GG::MenuItem(UserString("ALLOW_IMPERIAL_PP_STOCKPILE_USE"), false, false, allow_stockpile_action));
+                    popup->AddMenuItem(GG::MenuItem(UserString("ALLOW_IMPERIAL_PP_STOCKPILE_USE"), disabled, false, allow_stockpile_action));
                 }
             default:
                 break;
             }
 
             // pedia lookup
-            std::string item_name = "";
+            std::string item_name;
             switch (build_type) {
             case BT_BUILDING:
             case BT_STOCKPILE:
@@ -783,8 +787,7 @@ public:
     /** \name Structors */ //@{
     ProductionQueueWnd(GG::X x, GG::Y y, GG::X w, GG::Y h) :
         CUIWnd("", x, y, w, h, GG::INTERACTIVE | GG::RESIZABLE | GG::DRAGABLE | GG::ONTOP | PINABLE,
-               "production.queue"),
-        m_queue_lb(nullptr)
+               "production.queue")
     {}
 
     void CompleteConstruction() override {
@@ -827,7 +830,7 @@ private:
                              GG::Pt(ClientWidth(), ClientHeight() - GG::Y(CUIWnd::INNER_BORDER_ANGLE_OFFSET)));
     }
 
-    std::shared_ptr<ProdQueueListBox>   m_queue_lb;
+    std::shared_ptr<ProdQueueListBox> m_queue_lb;
 };
 
 //////////////////////////////////////////////////
@@ -835,9 +838,6 @@ private:
 //////////////////////////////////////////////////
 ProductionWnd::ProductionWnd(GG::X w, GG::Y h) :
     GG::Wnd(GG::X0, GG::Y0, w, h, GG::INTERACTIVE | GG::ONTOP),
-    m_production_info_panel(nullptr),
-    m_queue_wnd(nullptr),
-    m_build_designator_wnd(nullptr),
     m_order_issuing_enabled(false),
     m_empire_shown_id(ALL_EMPIRES)
 {}
@@ -859,6 +859,11 @@ void ProductionWnd::CompleteConstruction() {
 
     SetChildClippingMode(ClipToClient);
 
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+    using boost::placeholders::_3;
+    using boost::placeholders::_4;
+
     m_build_designator_wnd->AddBuildToQueueSignal.connect(
         boost::bind(&ProductionWnd::AddBuildToQueueSlot, this, _1, _2, _3, _4));
     m_build_designator_wnd->BuildQuantityChangedSignal.connect(
@@ -979,8 +984,8 @@ void ProductionWnd::ShowPlanetInEncyclopedia(int planet_id)
 void ProductionWnd::ShowTechInEncyclopedia(const std::string& tech_name)
 { m_build_designator_wnd->ShowTechInEncyclopedia(tech_name); }
 
-void ProductionWnd::ShowPartTypeInEncyclopedia(const std::string& part_type_name)
-{ m_build_designator_wnd->ShowPartTypeInEncyclopedia(part_type_name); }
+void ProductionWnd::ShowShipPartInEncyclopedia(const std::string& part_name)
+{ m_build_designator_wnd->ShowShipPartInEncyclopedia(part_name); }
 
 void ProductionWnd::ShowSpeciesInEncyclopedia(const std::string& species_name)
 { m_build_designator_wnd->ShowSpeciesInEncyclopedia(species_name); }
@@ -1025,7 +1030,9 @@ void ProductionWnd::SelectSystem(int system_id) {
     }
 }
 
-void ProductionWnd::QueueItemMoved(const GG::ListBox::iterator& row_it, const GG::ListBox::iterator& original_position_it) {
+void ProductionWnd::QueueItemMoved(const GG::ListBox::iterator& row_it,
+                                   const GG::ListBox::iterator& original_position_it)
+{
     if (!m_order_issuing_enabled)
         return;
     int client_empire_id = HumanClientApp::GetApp()->EmpireID();
@@ -1034,15 +1041,18 @@ void ProductionWnd::QueueItemMoved(const GG::ListBox::iterator& row_it, const GG
         return;
 
     // This precorrects the position for a factor in Empire::MoveProductionWithinQueue
-    int position = std::distance(m_queue_wnd->GetQueueListBox()->begin(), row_it);
-    int original_position = std::distance(m_queue_wnd->GetQueueListBox()->begin(), original_position_it);
-    auto direction = original_position < position;
-    int corrected_position = position + (direction ? 1 : 0);
+    int new_position = m_queue_wnd->GetQueueListBox()->IteraterIndex(row_it);
+    int original_position = m_queue_wnd->GetQueueListBox()->IteraterIndex(original_position_it);
+    auto direction = original_position < new_position;
+    int corrected_new_position = new_position + (direction ? 1 : 0);
 
-    HumanClientApp::GetApp()->Orders().IssueOrder(
-        std::make_shared<ProductionQueueOrder>(client_empire_id,
-                                               original_position,
-                                               corrected_position));
+    auto queue_it = empire->GetProductionQueue().find(original_position);
+
+    if (queue_it != empire->GetProductionQueue().end())
+        HumanClientApp::GetApp()->Orders().IssueOrder(
+            std::make_shared<ProductionQueueOrder>(ProductionQueueOrder::MOVE_ITEM_TO_INDEX,
+                                                   client_empire_id, queue_it->uuid,
+                                                   corrected_new_position));
     empire->UpdateProductionQueue();
 }
 
@@ -1060,12 +1070,16 @@ void ProductionWnd::UpdateQueue() {
     ScopedTimer timer("ProductionWnd::UpdateQueue");
 
     m_queue_wnd->SetEmpire(m_empire_shown_id);
-    QueueListBox* queue_lb = m_queue_wnd->GetQueueListBox();
+    ProdQueueListBox* queue_lb = m_queue_wnd->GetQueueListBox();
 
     // Capture the list scroll state
     // Try to preserve the same queue context with completely new queue items
-    std::size_t initial_offset_from_begin = std::distance(queue_lb->begin(), queue_lb->FirstRowShown());
-    std::size_t initial_offset_to_end = std::distance(queue_lb->FirstRowShown(), queue_lb->end());
+    int initial_offset_from_begin = queue_lb->IteraterIndex(queue_lb->FirstRowShown());
+    int initial_offset_to_end = 0;
+    if (initial_offset_from_begin < 0)
+        ErrorLogger() << "ProductionWnd::UpdateQueue initial offset from begin was invalid...";
+    else
+        initial_offset_to_end = std::distance(queue_lb->FirstRowShown(), queue_lb->end());
     bool initial_last_visible_row_is_end(queue_lb->LastVisibleRow() == queue_lb->end());
 
     queue_lb->Clear();
@@ -1074,11 +1088,13 @@ void ProductionWnd::UpdateQueue() {
     if (!empire)
         return;
 
+    namespace ph = boost::placeholders;
+
     int i = 0;
     for (const ProductionQueue::Element& elem : empire->GetProductionQueue()) {
         auto row = GG::Wnd::Create<QueueRow>(queue_lb->RowWidth(), elem, i);
         row->RowQuantChangedSignal.connect(
-            boost::bind(&ProductionWnd::ChangeBuildQuantityBlockSlot, this, _1, _2, _3));
+            boost::bind(&ProductionWnd::ChangeBuildQuantityBlockSlot, this, ph::_1, ph::_2, ph::_3));
         queue_lb->Insert(row);
         ++i;
     }
@@ -1089,12 +1105,12 @@ void ProductionWnd::UpdateQueue() {
         queue_lb->SetFirstRowShown(queue_lb->begin());
 
     // If we were not at the bottom then keep the same first row position
-    else if (!initial_last_visible_row_is_end && initial_offset_from_begin < queue_lb->NumRows())
+    else if (!initial_last_visible_row_is_end && initial_offset_from_begin < static_cast<int>(queue_lb->NumRows()))
         queue_lb->SetFirstRowShown(std::next(queue_lb->begin(), initial_offset_from_begin));
 
     // otherwise keep the same relative position from the bottom to
     // preserve the end of list dead space
-    else if (initial_offset_to_end < queue_lb->NumRows())
+    else if (initial_offset_to_end < static_cast<int>(queue_lb->NumRows()))
         queue_lb->SetFirstRowShown(std::next(queue_lb->begin(), queue_lb->NumRows() - initial_offset_to_end));
     else
         queue_lb->SetFirstRowShown(queue_lb->begin());
@@ -1111,7 +1127,7 @@ void ProductionWnd::UpdateInfoPanel() {
     }
 
     const ProductionQueue& queue = empire->GetProductionQueue();
-    float PPs = empire->ProductionPoints();
+    float PPs = empire->ResourceOutput(RE_INDUSTRY);
     float total_queue_cost = queue.TotalPPsSpent();
     float stockpile = empire->GetResourcePool(RE_INDUSTRY)->Stockpile();
     float stockpile_use = boost::accumulate(empire->GetProductionQueue().AllocatedStockpilePP() | boost::adaptors::map_values, 0.0f);
@@ -1121,7 +1137,7 @@ void ProductionWnd::UpdateInfoPanel() {
 
     // find if there is a local location
     int prod_loc_id = this->SelectedPlanetID();
-    auto loc_obj = GetUniverseObject(prod_loc_id);
+    auto loc_obj = Objects().get(prod_loc_id);
     if (!loc_obj) {
         // clear local info...
         m_production_info_panel->ClearLocalInfo();
@@ -1178,7 +1194,8 @@ void ProductionWnd::AddBuildToQueueSlot(const ProductionQueue::ProductionItem& i
         return;
 
     HumanClientApp::GetApp()->Orders().IssueOrder(
-        std::make_shared<ProductionQueueOrder>(client_empire_id, item, number, location, pos));
+        std::make_shared<ProductionQueueOrder>(ProductionQueueOrder::PLACE_IN_QUEUE,
+                                               client_empire_id, item, number, location, pos));
 
     empire->UpdateProductionQueue();
     m_build_designator_wnd->CenterOnBuild(pos >= 0 ? pos : m_queue_wnd->GetQueueListBox()->NumRows() - 1);
@@ -1192,8 +1209,13 @@ void ProductionWnd::ChangeBuildQuantitySlot(int queue_idx, int quantity) {
     if (!empire)
         return;
 
-    HumanClientApp::GetApp()->Orders().IssueOrder(
-        std::make_shared<ProductionQueueOrder>(client_empire_id, queue_idx, quantity, true));
+    auto queue_it = empire->GetProductionQueue().find(queue_idx);
+
+    if (queue_it != empire->GetProductionQueue().end())
+        HumanClientApp::GetApp()->Orders().IssueOrder(
+            std::make_shared<ProductionQueueOrder>(ProductionQueueOrder::SET_QUANTITY,
+                                                   client_empire_id, queue_it->uuid,
+                                                   quantity));
 
     empire->UpdateProductionQueue();
 }
@@ -1206,8 +1228,13 @@ void ProductionWnd::ChangeBuildQuantityBlockSlot(int queue_idx, int quantity, in
     if (!empire)
         return;
 
-    HumanClientApp::GetApp()->Orders().IssueOrder(
-        std::make_shared<ProductionQueueOrder>(client_empire_id, queue_idx, quantity, blocksize));
+    auto queue_it = empire->GetProductionQueue().find(queue_idx);
+
+    if (queue_it != empire->GetProductionQueue().end())
+        HumanClientApp::GetApp()->Orders().IssueOrder(
+            std::make_shared<ProductionQueueOrder>(ProductionQueueOrder::SET_QUANTITY_AND_BLOCK_SIZE,
+                                                   client_empire_id, queue_it->uuid,
+                                                   quantity, blocksize));
 
     empire->UpdateProductionQueue();
 }
@@ -1220,8 +1247,15 @@ void ProductionWnd::DeleteQueueItem(GG::ListBox::iterator it) {
     if (!empire)
         return;
 
-    HumanClientApp::GetApp()->Orders().IssueOrder(
-        std::make_shared<ProductionQueueOrder>(client_empire_id, std::distance(m_queue_wnd->GetQueueListBox()->begin(), it)));
+    auto idx = m_queue_wnd->GetQueueListBox()->IteraterIndex(it);
+    auto queue_it = empire->GetProductionQueue().find(idx);
+
+    if (queue_it != empire->GetProductionQueue().end()) {
+        DebugLogger() << "DeleteQueueItem idx: " << idx << "  item: " << queue_it->Dump();
+        HumanClientApp::GetApp()->Orders().IssueOrder(
+            std::make_shared<ProductionQueueOrder>(ProductionQueueOrder::REMOVE_FROM_QUEUE,
+                                                   client_empire_id, queue_it->uuid));
+    }
 
     empire->UpdateProductionQueue();
 }
@@ -1231,14 +1265,13 @@ void ProductionWnd::QueueItemClickedSlot(GG::ListBox::iterator it, const GG::Pt&
         if (modkeys & GG::MOD_KEY_CTRL)
             DeleteQueueItem(it);
         else
-            m_build_designator_wnd->CenterOnBuild(std::distance(m_queue_wnd->GetQueueListBox()->begin(), it));
+            m_build_designator_wnd->CenterOnBuild(m_queue_wnd->GetQueueListBox()->IteraterIndex(it));
     }
 }
 
 void ProductionWnd::QueueItemDoubleClickedSlot(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys) {
-    if (m_queue_wnd->GetQueueListBox()->DisplayingValidQueueItems()) {
-        m_build_designator_wnd->CenterOnBuild(std::distance(m_queue_wnd->GetQueueListBox()->begin(), it), true);
-    }
+    if (m_queue_wnd->GetQueueListBox()->DisplayingValidQueueItems())
+        m_build_designator_wnd->CenterOnBuild(m_queue_wnd->GetQueueListBox()->IteraterIndex(it), true);
 }
 
 void ProductionWnd::QueueItemRallied(GG::ListBox::iterator it, int object_id) {
@@ -1257,9 +1290,14 @@ void ProductionWnd::QueueItemRallied(GG::ListBox::iterator it, int object_id) {
     if (rally_point_id == INVALID_OBJECT_ID)
         return;
 
-    HumanClientApp::GetApp()->Orders().IssueOrder(
-        std::make_shared<ProductionQueueOrder>(client_empire_id, std::distance(m_queue_wnd->GetQueueListBox()->begin(), it),
-                                               rally_point_id, false, false));
+    auto idx = m_queue_wnd->GetQueueListBox()->IteraterIndex(it);
+    auto queue_it = empire->GetProductionQueue().find(idx);
+
+    if (queue_it != empire->GetProductionQueue().end())
+        HumanClientApp::GetApp()->Orders().IssueOrder(
+            std::make_shared<ProductionQueueOrder>(ProductionQueueOrder::SET_RALLY_POINT,
+                                                   client_empire_id, queue_it->uuid,
+                                                   rally_point_id));
 
     empire->UpdateProductionQueue();
 }
@@ -1272,9 +1310,13 @@ void ProductionWnd::QueueItemPaused(GG::ListBox::iterator it, bool pause) {
     if (!empire)
         return;
 
-    HumanClientApp::GetApp()->Orders().IssueOrder(
-        std::make_shared<ProductionQueueOrder>(client_empire_id, std::distance(m_queue_wnd->GetQueueListBox()->begin(), it),
-                                               pause, -1.0f));
+    auto idx = m_queue_wnd->GetQueueListBox()->IteraterIndex(it);
+    auto queue_it = empire->GetProductionQueue().find(idx);
+    auto action = pause ? ProductionQueueOrder::PAUSE_PRODUCTION : ProductionQueueOrder::RESUME_PRODUCTION;
+
+    if (queue_it != empire->GetProductionQueue().end())
+        HumanClientApp::GetApp()->Orders().IssueOrder(
+            std::make_shared<ProductionQueueOrder>(action, client_empire_id, queue_it->uuid));
 
     empire->UpdateProductionQueue();
 }
@@ -1287,9 +1329,13 @@ void ProductionWnd::QueueItemDuped(GG::ListBox::iterator it) {
     if (!empire)
         return;
 
-    HumanClientApp::GetApp()->Orders().IssueOrder(
-        std::make_shared<ProductionQueueOrder>(client_empire_id, std::distance(m_queue_wnd->GetQueueListBox()->begin(), it),
-                                               -1.0f, -1.0f));
+    auto idx = m_queue_wnd->GetQueueListBox()->IteraterIndex(it);
+    auto queue_it = empire->GetProductionQueue().find(idx);
+
+    if (queue_it != empire->GetProductionQueue().end())
+        HumanClientApp::GetApp()->Orders().IssueOrder(
+            std::make_shared<ProductionQueueOrder>(ProductionQueueOrder::DUPLICATE_ITEM,
+                                                   client_empire_id, queue_it->uuid));
 
     empire->UpdateProductionQueue();
 }
@@ -1302,9 +1348,13 @@ void ProductionWnd::QueueItemSplit(GG::ListBox::iterator it) {
     if (!empire)
         return;
 
-    HumanClientApp::GetApp()->Orders().IssueOrder(
-        std::make_shared<ProductionQueueOrder>(client_empire_id, std::distance(m_queue_wnd->GetQueueListBox()->begin(), it),
-                                               -1.0f));
+    auto idx = m_queue_wnd->GetQueueListBox()->IteraterIndex(it);
+    auto queue_it = empire->GetProductionQueue().find(idx);
+
+    if (queue_it != empire->GetProductionQueue().end())
+        HumanClientApp::GetApp()->Orders().IssueOrder(
+            std::make_shared<ProductionQueueOrder>(ProductionQueueOrder::SPLIT_INCOMPLETE,
+                                                   client_empire_id, queue_it->uuid));
 
     empire->UpdateProductionQueue();
 }
@@ -1317,9 +1367,13 @@ void ProductionWnd::QueueItemUseImperialPP(GG::ListBox::iterator it, bool allow)
     if (!empire)
         return;
 
-    HumanClientApp::GetApp()->Orders().IssueOrder(
-        OrderPtr(new ProductionQueueOrder(client_empire_id, std::distance(m_queue_wnd->GetQueueListBox()->begin(), it),
-                                          allow, -1.0f, -1.0f)));
+    auto idx = m_queue_wnd->GetQueueListBox()->IteraterIndex(it);
+    auto queue_it = empire->GetProductionQueue().find(idx);
+    auto action = allow ? ProductionQueueOrder::ALLOW_STOCKPILE_USE : ProductionQueueOrder::DISALLOW_STOCKPILE_USE;
+
+    if (queue_it != empire->GetProductionQueue().end())
+        HumanClientApp::GetApp()->Orders().IssueOrder(
+            OrderPtr(new ProductionQueueOrder(action, client_empire_id, queue_it->uuid)));
 
     empire->UpdateProductionQueue();
 }
