@@ -3,7 +3,6 @@
 #include "../util/i18n.h"
 #include "../util/Logger.h"
 
-#include <GG/DrawUtil.h>
 #include <GG/WndEvent.h>
 
 #include <boost/cast.hpp>
@@ -12,7 +11,7 @@
 // PromptRow
 ////////////////////////////////////////////////////////////
 PromptRow::PromptRow(GG::X w, const std::string& prompt) :
-    GG::ListBox::Row(w, GG::Y(20), ""),
+    GG::ListBox::Row(w, GG::Y(20)),
     m_prompt(
         GG::Wnd::Create<CUILabel>(
             prompt,
@@ -24,7 +23,7 @@ void PromptRow::CompleteConstruction() {
 
     m_prompt->MoveTo(GG::Pt(GG::X(2), GG::Y(2)));
     m_prompt->Resize(GG::Pt(Width() - 10, Height()));
-    m_prompt->SetTextColor(GG::LightColor(ClientUI::TextColor()));
+    m_prompt->SetTextColor(GG::LightenClr(ClientUI::TextColor()));
     m_prompt->ClipText(true);
     Resize(GG::Pt(Width(), m_prompt->Height()));
     push_back(m_prompt);
@@ -62,14 +61,16 @@ void QueueListBox::CompleteConstruction() {
 
     ShowPromptSlot();
 
+    namespace ph = boost::placeholders;
+
     BeforeInsertRowSignal.connect(
-        boost::bind(&QueueListBox::EnsurePromptHiddenSlot, this, _1));
+        boost::bind(&QueueListBox::EnsurePromptHiddenSlot, this, ph::_1));
     AfterEraseRowSignal.connect(
-        boost::bind(&QueueListBox::ShowPromptConditionallySlot, this, _1));
+        boost::bind(&QueueListBox::ShowPromptConditionallySlot, this, ph::_1));
     ClearedRowsSignal.connect(
         boost::bind(&QueueListBox::ShowPromptSlot, this));
     GG::ListBox::RightClickedRowSignal.connect(
-        boost::bind(&QueueListBox::ItemRightClicked, this, _1, _2, _3));
+        boost::bind(&QueueListBox::ItemRightClicked, this, ph::_1, ph::_2, ph::_3));
 }
 
 GG::X QueueListBox::RowWidth() const
@@ -156,6 +157,19 @@ void QueueListBox::DragDropLeave() {
     m_show_drop_point = false;
 }
 
+int QueueListBox::IteraterIndex(const const_iterator it) {
+    if (it == this->end())
+        return -1;
+
+    size_t dist = 0;
+    for (auto qit = this->begin(); qit != this->end(); ++qit) {
+        if (qit == it)
+            return dist;
+        dist++;
+    }
+    return -1;
+}
+
 void QueueListBox::EnableOrderIssuing(bool enable/* = true*/) {
     m_order_issuing_enabled = enable;
     AllowDrops(enable);
@@ -183,27 +197,36 @@ void QueueListBox::SetEmptyPromptText(const std::string prompt) {
 
 std::function<void()> QueueListBox::MoveToTopAction(GG::ListBox::iterator it) {
     return [it, this]() {
-        ListBox::Insert(*it, begin(), true);
+        if (OrderIssuingEnabled())
+            ListBox::Insert(*it, begin(), true);
     };
 }
 
 std::function<void()> QueueListBox::MoveToBottomAction(GG::ListBox::iterator it) {
     return [it, this]() {
-        ListBox::Insert(*it, end(), true);
+        if (OrderIssuingEnabled())
+            ListBox::Insert(*it, end(), true);
     };
 }
 
-std::function<void()> QueueListBox::DeleteAction(GG::ListBox::iterator it) const
-{ return [it, this]() { QueueItemDeletedSignal(it); }; }
+std::function<void()> QueueListBox::DeleteAction(GG::ListBox::iterator it) const {
+    return [it, this]() {
+        if (OrderIssuingEnabled())
+            QueueItemDeletedSignal(it);
+    };
+}
 
 void QueueListBox::ItemRightClicked(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys)
 { this->ItemRightClickedImpl(it, pt, modkeys); }
 
 void QueueListBox::ItemRightClickedImpl(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys) {
     auto popup = GG::Wnd::Create<CUIPopupMenu>(pt.x, pt.y);
-    popup->AddMenuItem(GG::MenuItem(UserString("MOVE_UP_QUEUE_ITEM"),   false, false, MoveToTopAction(it)));
-    popup->AddMenuItem(GG::MenuItem(UserString("MOVE_DOWN_QUEUE_ITEM"), false, false, MoveToBottomAction(it)));
-    popup->AddMenuItem(GG::MenuItem(UserString("DELETE_QUEUE_ITEM"),    false, false, DeleteAction(it)));
+
+    bool disabled = !OrderIssuingEnabled();
+
+    popup->AddMenuItem(GG::MenuItem(UserString("MOVE_UP_QUEUE_ITEM"),   disabled, false, MoveToTopAction(it)));
+    popup->AddMenuItem(GG::MenuItem(UserString("MOVE_DOWN_QUEUE_ITEM"), disabled, false, MoveToBottomAction(it)));
+    popup->AddMenuItem(GG::MenuItem(UserString("DELETE_QUEUE_ITEM"),    disabled, false, DeleteAction(it)));
     popup->Run();
 }
 
