@@ -13,7 +13,6 @@
 #include "../util/ScopedTimer.h"
 #include "../client/human/HumanClientApp.h"
 
-#include <GG/DrawUtil.h>
 #include <GG/Layout.h>
 #include <GG/StaticGraphic.h>
 
@@ -68,10 +67,10 @@ namespace {
     //////////////////////////////////////////////////
     struct QueueRow : GG::ListBox::Row {
         QueueRow(GG::X w, const ResearchQueue::Element& queue_element) :
-            GG::ListBox::Row(w, QueueTechPanel::DefaultHeight(), "RESEARCH_QUEUE_ROW"),
-            elem(queue_element),
-            panel(nullptr)
+            GG::ListBox::Row(w, QueueTechPanel::DefaultHeight()),
+            elem(queue_element)
         {
+            SetDragDropDataType("RESEARCH_QUEUE_ROW");
             RequirePreRender();
             Resize(GG::Pt(w, QueueTechPanel::DefaultHeight()));
         }
@@ -153,7 +152,7 @@ namespace {
             m_total_turns = tech->ResearchTime(m_empire_id);
 
         GG::Clr clr = m_in_progress
-                        ? GG::LightColor(ClientUI::ResearchableTechTextAndBorderColor())
+                        ? GG::LightenClr(ClientUI::ResearchableTechTextAndBorderColor())
                         : ClientUI::ResearchableTechTextAndBorderColor();
 
         GG::Y top(MARGIN);
@@ -184,12 +183,12 @@ namespace {
         }
         GG::Clr outline_color = ClientUI::ResearchableTechFillColor();
         if (m_in_progress)
-            outline_color = GG::LightColor(outline_color);
+            outline_color = GG::LightenClr(outline_color);
 
         m_progress_bar = GG::Wnd::Create<MultiTurnProgressBar>(total_time,
                                                                perc_complete,
                                                                next_progress,
-                                                               GG::LightColor(ClientUI::TechWndProgressBarBackgroundColor()),
+                                                               GG::LightenClr(ClientUI::TechWndProgressBarBackgroundColor()),
                                                                ClientUI::TechWndProgressBarColor(),
                                                                outline_color);
 
@@ -232,8 +231,8 @@ namespace {
     }
 
     void QueueTechPanel::Render() {
-        GG::Clr fill = m_in_progress ? GG::LightColor(ClientUI::ResearchableTechFillColor()) : ClientUI::ResearchableTechFillColor();
-        GG::Clr text_and_border = m_in_progress ? GG::LightColor(ClientUI::ResearchableTechTextAndBorderColor()) : ClientUI::ResearchableTechTextAndBorderColor();
+        GG::Clr fill = m_in_progress ? GG::LightenClr(ClientUI::ResearchableTechFillColor()) : ClientUI::ResearchableTechFillColor();
+        GG::Clr text_and_border = m_in_progress ? GG::LightenClr(ClientUI::ResearchableTechTextAndBorderColor()) : ClientUI::ResearchableTechTextAndBorderColor();
 
         glDisable(GL_TEXTURE_2D);
         Draw(fill, true);
@@ -313,9 +312,11 @@ protected:
 
         auto popup = GG::Wnd::Create<CUIPopupMenu>(pt.x, pt.y);
 
-        popup->AddMenuItem(GG::MenuItem(UserString("MOVE_UP_QUEUE_ITEM"),   false, false, MoveToTopAction(it)));
-        popup->AddMenuItem(GG::MenuItem(UserString("MOVE_DOWN_QUEUE_ITEM"), false, false, MoveToBottomAction(it)));
-        popup->AddMenuItem(GG::MenuItem(UserString("DELETE_QUEUE_ITEM"),    false, false, DeleteAction(it)));
+        bool disabled = !OrderIssuingEnabled();
+
+        popup->AddMenuItem(GG::MenuItem(UserString("MOVE_UP_QUEUE_ITEM"),   disabled, false, MoveToTopAction(it)));
+        popup->AddMenuItem(GG::MenuItem(UserString("MOVE_DOWN_QUEUE_ITEM"), disabled, false, MoveToBottomAction(it)));
+        popup->AddMenuItem(GG::MenuItem(UserString("DELETE_QUEUE_ITEM"),    disabled, false, DeleteAction(it)));
 
         auto& row = *it;
         QueueRow* queue_row = row ? dynamic_cast<QueueRow*>(row.get()) : nullptr;
@@ -324,9 +325,9 @@ protected:
 
         // pause / resume commands
         if (queue_row->elem.paused) {
-            popup->AddMenuItem(GG::MenuItem(UserString("RESUME"),           false, false, resume_action));
+            popup->AddMenuItem(GG::MenuItem(UserString("RESUME"), disabled, false, resume_action));
         } else {
-            popup->AddMenuItem(GG::MenuItem(UserString("PAUSE"),            false, false, pause_action));
+            popup->AddMenuItem(GG::MenuItem(UserString("PAUSE"),  disabled, false, pause_action));
         }
 
         // pedia lookup
@@ -354,8 +355,7 @@ public:
     /** \name Structors */ //@{
     ResearchQueueWnd(GG::X x, GG::Y y, GG::X w, GG::Y h) :
         CUIWnd("", x, y, w, h, GG::INTERACTIVE | GG::RESIZABLE | GG::DRAGABLE | GG::ONTOP | PINABLE,
-               "research.queue"),
-        m_queue_lb(nullptr)
+               "research.queue")
     {}
 
     void CompleteConstruction() override {
@@ -383,9 +383,9 @@ public:
             DoLayout();
     }
 
-    ResearchQueueListBox*   GetQueueListBox() { return m_queue_lb.get(); }
+    ResearchQueueListBox* GetQueueListBox() { return m_queue_lb.get(); }
 
-    void                SetEmpire(int id) {
+    void SetEmpire(int id) {
         if (const Empire* empire = GetEmpire(id))
             SetName(boost::io::str(FlexibleFormat(UserString("RESEARCH_QUEUE_EMPIRE")) % empire->Name()));
         else
@@ -408,9 +408,6 @@ private:
 //////////////////////////////////////////////////
 ResearchWnd::ResearchWnd(GG::X w, GG::Y h, bool initially_hidden /*= true*/) :
     GG::Wnd(GG::X0, GG::Y0, w, h, GG::INTERACTIVE | GG::ONTOP),
-    m_research_info_panel(nullptr),
-    m_queue_wnd(nullptr),
-    m_tech_tree_wnd(nullptr),
     m_enabled(false),
     m_empire_shown_id(ALL_EMPIRES)
 {
@@ -423,6 +420,10 @@ ResearchWnd::ResearchWnd(GG::X w, GG::Y h, bool initially_hidden /*= true*/) :
     m_queue_wnd = GG::Wnd::Create<ResearchQueueWnd>(GG::X0, GG::Y(100), queue_width, GG::Y(ClientSize().y - 100));
     m_tech_tree_wnd = GG::Wnd::Create<TechTreeWnd>(tech_tree_wnd_size.x, tech_tree_wnd_size.y, initially_hidden);
 
+    using boost::placeholders::_1;
+    using boost::placeholders::_2;
+    using boost::placeholders::_3;
+
     m_queue_wnd->GetQueueListBox()->MovedRowSignal.connect(
         boost::bind(&ResearchWnd::QueueItemMoved, this, _1, _2));
     m_queue_wnd->GetQueueListBox()->QueueItemDeletedSignal.connect(
@@ -535,20 +536,29 @@ bool ResearchWnd::PediaVisible()
 { return m_tech_tree_wnd->PediaVisible(); }
 
 void ResearchWnd::QueueItemMoved(const GG::ListBox::iterator& row_it, const GG::ListBox::iterator& original_position_it) {
-    if (QueueRow* queue_row = boost::polymorphic_downcast<QueueRow*>(row_it->get())) {
-        int empire_id = HumanClientApp::GetApp()->EmpireID();
+    if (!m_enabled)
+        return;
 
-        // This precorrects the position for a factor in Empire::PlaceTechInQueue
-        auto position = std::distance(m_queue_wnd->GetQueueListBox()->begin(), row_it);
-        auto original_position = std::distance(m_queue_wnd->GetQueueListBox()->begin(), original_position_it);
-        auto orginal_greater = original_position > position;
-        auto corrected_position = position + (orginal_greater ? 0 : 1);
+    auto queue_row = boost::polymorphic_downcast<QueueRow*>(row_it->get());
+    if (!queue_row)
+        return;
 
-        HumanClientApp::GetApp()->Orders().IssueOrder(
-            std::make_shared<ResearchQueueOrder>(empire_id, queue_row->elem.name, static_cast<int>(corrected_position)));
-        if (Empire* empire = GetEmpire(empire_id))
-            empire->UpdateResearchQueue();
-    }
+    // This precorrects the position for a factor in Empire::PlaceTechInQueue
+    int new_position = m_queue_wnd->GetQueueListBox()->IteraterIndex(row_it);
+    int original_position = m_queue_wnd->GetQueueListBox()->IteraterIndex(original_position_it);
+    auto direction = original_position < new_position;
+    int corrected_new_position = new_position + (direction ? 1 : 0);
+
+    int empire_id = HumanClientApp::GetApp()->EmpireID();
+    if (empire_id == ALL_EMPIRES)
+        return;
+
+    HumanClientApp::GetApp()->Orders().IssueOrder(
+        std::make_shared<ResearchQueueOrder>(empire_id, queue_row->elem.name,
+                                                static_cast<int>(corrected_new_position)));
+
+    if (Empire* empire = GetEmpire(empire_id))
+        empire->UpdateResearchQueue();
 }
 
 void ResearchWnd::Sanitize()
@@ -577,7 +587,9 @@ void ResearchWnd::UpdateQueue() {
     m_queue_wnd->SetEmpire(m_empire_shown_id);
 
     QueueListBox* queue_lb = m_queue_wnd->GetQueueListBox();
-    std::size_t first_visible_queue_row = std::distance(queue_lb->begin(), queue_lb->FirstRowShown());
+    auto first_visible_queue_row = m_queue_wnd->GetQueueListBox()->IteraterIndex(queue_lb->FirstRowShown());
+    if (first_visible_queue_row < 0)
+        first_visible_queue_row = 0;
     queue_lb->Clear();
 
     const Empire* empire = GetEmpire(HumanClientApp::GetApp()->EmpireID());
@@ -591,7 +603,7 @@ void ResearchWnd::UpdateQueue() {
 
     if (!queue_lb->Empty())
         queue_lb->BringRowIntoView(--queue_lb->end());
-    if (first_visible_queue_row < queue_lb->NumRows())
+    if (first_visible_queue_row < static_cast<int>(queue_lb->NumRows()))
         queue_lb->BringRowIntoView(std::next(queue_lb->begin(), first_visible_queue_row));
 }
 
@@ -635,7 +647,7 @@ void ResearchWnd::AddTechsToQueueSlot(const std::vector<std::string>& tech_vec,
         // (ii) prioritizing a tech by placing it and any not-yet-completed techs, whether currently queued or not,
         // to the front of the queue.  If at some time this routine is desired to be used to move a group of techs from 
         // early positions in the queue to later positions, the below tests would need to change.
-        
+
         // If we're adding to the end of the queue (pos==-1), we'll need to put in a ResearchQueueOrder iff the tech is 
         // not yet in the queue. Otherwise (adding to beginning) we'll need to put in a ResearchQueueOrder if the tech is
         // not yet in the queue or if the tech's current position in the queue is after the desired position.  When 
@@ -657,41 +669,42 @@ void ResearchWnd::AddTechsToQueueSlot(const std::vector<std::string>& tech_vec,
 }
 
 void ResearchWnd::DeleteQueueItem(GG::ListBox::iterator it) {
-    if (!m_enabled)
+    if (!m_enabled || m_queue_wnd->GetQueueListBox()->IteraterIndex(it) < 0)
         return;
+
     int empire_id = HumanClientApp::GetApp()->EmpireID();
     OrderSet& orders = HumanClientApp::GetApp()->Orders();
-    if (QueueRow* queue_row = boost::polymorphic_downcast<QueueRow*>(it->get()))
+    if (auto queue_row = boost::polymorphic_downcast<QueueRow*>(it->get()))
         orders.IssueOrder(std::make_shared<ResearchQueueOrder>(empire_id, queue_row->elem.name));
-    if (Empire* empire = GetEmpire(empire_id))
+    if (auto empire = GetEmpire(empire_id))
         empire->UpdateResearchQueue();
 }
 
 void ResearchWnd::QueueItemClickedSlot(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys) {
-    if (m_queue_wnd->GetQueueListBox()->DisplayingValidQueueItems()) {
-        if (modkeys & GG::MOD_KEY_CTRL) {
+    if (m_queue_wnd->GetQueueListBox()->IteraterIndex(it) < 0 || !m_queue_wnd->GetQueueListBox()->DisplayingValidQueueItems())
+        return;
+
+    if (modkeys & GG::MOD_KEY_CTRL) {
+        if (m_enabled)
             DeleteQueueItem(it);
-        } else {
-            auto queue_row = boost::polymorphic_downcast<QueueRow*>(it->get());
-            if (!queue_row)
-                return;
+    } else {
+        if (auto queue_row = boost::polymorphic_downcast<QueueRow*>(it->get()))
             ShowTech(queue_row->elem.name, false);
-        }
     }
 }
 
 void ResearchWnd::QueueItemDoubleClickedSlot(GG::ListBox::iterator it, const GG::Pt& pt, const GG::Flags<GG::ModKey>& modkeys) {
-    if (m_queue_wnd->GetQueueListBox()->DisplayingValidQueueItems()) {
-        QueueRow* queue_row = boost::polymorphic_downcast<QueueRow*>(it->get());
-        if (!queue_row)
-            return;
+    if (m_queue_wnd->GetQueueListBox()->IteraterIndex(it) < 0 || !m_queue_wnd->GetQueueListBox()->DisplayingValidQueueItems())
+        return;
+
+    if (auto queue_row = boost::polymorphic_downcast<QueueRow*>(it->get()))
         ShowTech(queue_row->elem.name);
-    }
 }
 
 void ResearchWnd::QueueItemPaused(GG::ListBox::iterator it, bool pause) {
-    if (!m_enabled)
+    if (!m_enabled || m_queue_wnd->GetQueueListBox()->IteraterIndex(it) < 0)
         return;
+
     int client_empire_id = HumanClientApp::GetApp()->EmpireID();
     Empire* empire = GetEmpire(client_empire_id);
     if (!empire)
@@ -707,7 +720,7 @@ void ResearchWnd::QueueItemPaused(GG::ListBox::iterator it, bool pause) {
 }
 
 
-void ResearchWnd::EnableOrderIssuing(bool enable/* = true*/) {
+void ResearchWnd::EnableOrderIssuing(bool enable) {
     m_enabled = enable;
     m_queue_wnd->GetQueueListBox()->EnableOrderIssuing(m_enabled);
 }
